@@ -13,6 +13,7 @@ from web_foundation.kernel.dispatcher import IDispatcher
 from web_foundation.app.resources.cache.cache import AppCache
 from web_foundation.app.resources.cache.memory import InMemoryCache
 from web_foundation.app.service import Service
+from web_foundation.kernel.logger import setup_loggers, LoggerSettings
 from web_foundation.workers.worker import GenWorker
 
 AppConfig = TypeVar("AppConfig", bound=BaseSettings)
@@ -29,9 +30,11 @@ class App(Generic[AppConfig, GenWorker]):
     def __init__(self, config: providers.Configuration, debug: bool = False):
         self.debug = debug
         self.name = config.get("app_name")
+        self.config = config
         self.workers = {}
         self.services = {}
         self.dispatcher = IDispatcher()
+        self._create_logger()
 
     @inject
     async def _before_app_run(self, app_container: AppContainer = Provide["<container>"]):
@@ -75,6 +78,12 @@ class App(Generic[AppConfig, GenWorker]):
             container.wire(modules=[worker.__module__])
             worker.wire_worker(container)
 
+    def _create_logger(self) -> None:
+        logger_conf = self.config.get("logger")
+        if logger_conf:
+            logger_conf = LoggerSettings(**logger_conf)
+        setup_loggers(logger_conf)
+
     def perform(self) -> List[Future[Any]]:
         """
         Call performs from isolates and return all isolates Futures
